@@ -1,9 +1,9 @@
 #' @importFrom jsonlite fromJSON
 #' @importFrom utils read.csv
 #' @importFrom httr GET content set_config config
-#' @importFrom readr cols
 retrieve_indicator <- function(IndicatorIDs, ProfileIDs, ChildAreaTypeIDs, ParentAreaTypeIDs){
         path <- "https://fingertips.phe.org.uk/api/"
+        types <- "icccccccccccnnnnicccci"
         set_config(config(ssl_verifypeer = 0L))
         fingertips_data <- data.frame()
         for (i in 1:length(IndicatorIDs)) {
@@ -29,7 +29,7 @@ retrieve_indicator <- function(IndicatorIDs, ProfileIDs, ChildAreaTypeIDs, Paren
                                                                   "&include_sortable_time_periods=yes")
                                         }
                                 }
-                                fingertips_data <- rbind(dataurl %>% GET %>% content("parsed", type = "text/csv", encoding = "UTF-8", col_types = cols()),
+                                fingertips_data <- rbind(dataurl %>% GET %>% content("parsed", type = "text/csv", encoding = "UTF-8", col_types = types),
                                                          fingertips_data)
                         }
                 }
@@ -40,9 +40,10 @@ retrieve_indicator <- function(IndicatorIDs, ProfileIDs, ChildAreaTypeIDs, Paren
 #' @importFrom jsonlite fromJSON
 #' @importFrom utils read.csv
 #' @importFrom httr GET content set_config config
-#' @importFrom readr cols
 retrieve_domain <- function(DomainIDs, ChildAreaTypeIDs, ParentAreaTypeIDs){
         path <- "https://fingertips.phe.org.uk/api/"
+        types <- "icccccccccccnnnnicccci"
+        set_config(config(ssl_verifypeer = 0L))
         fingertips_data <- data.frame()
         for (DomainID in DomainIDs) {
                 for (ChildAreaTypeID in ChildAreaTypeIDs) {
@@ -51,7 +52,7 @@ retrieve_domain <- function(DomainIDs, ChildAreaTypeIDs, ParentAreaTypeIDs){
                                                   sprintf("all_data/csv/by_group_id?child_area_type_id=%s&parent_area_type_id=%s&group_id=%s",
                                                           ChildAreaTypeID,ParentAreaTypeID,DomainID),
                                                   "&include_sortable_time_periods=yes")
-                                fingertips_data <- rbind(dataurl %>% GET %>% content("parsed", type = "text/csv", encoding = "UTF-8", col_types = cols()),
+                                fingertips_data <- rbind(dataurl %>% GET %>% content("parsed", type = "text/csv", encoding = "UTF-8", col_types = types),
                                                          fingertips_data)
                         }
                 }
@@ -62,9 +63,10 @@ retrieve_domain <- function(DomainIDs, ChildAreaTypeIDs, ParentAreaTypeIDs){
 #' @importFrom jsonlite fromJSON
 #' @importFrom utils read.csv
 #' @importFrom httr GET content set_config config
-#' @importFrom readr cols
 retrieve_profile <- function(ProfileIDs, ChildAreaTypeIDs, ParentAreaTypeIDs){
         path <- "https://fingertips.phe.org.uk/api/"
+        types <- "icccccccccccnnnnicccci"
+        set_config(config(ssl_verifypeer = 0L))
         fingertips_data <- data.frame()
         for (ProfileID in ProfileIDs) {
                 for (ChildAreaTypeID in ChildAreaTypeIDs) {
@@ -73,7 +75,7 @@ retrieve_profile <- function(ProfileIDs, ChildAreaTypeIDs, ParentAreaTypeIDs){
                                                   sprintf("all_data/csv/by_profile_id?child_area_type_id=%s&parent_area_type_id=%s&profile_id=%s",
                                                           ChildAreaTypeID,ParentAreaTypeID,ProfileID),
                                                   "&include_sortable_time_periods=yes")
-                                fingertips_data <- rbind(dataurl %>% GET %>% content("parsed", type = "text/csv", encoding = "UTF-8", col_types = cols()),
+                                fingertips_data <- rbind(dataurl %>% GET %>% content("parsed", type = "text/csv", encoding = "UTF-8", col_types = types),
                                                          fingertips_data)
                         }
                 }
